@@ -45,14 +45,14 @@ int parse_reply(const char *reply, char **token, char **secret) {
     ok=0;
     if (token)  *token =strdup(&(rv[0][12]));
     if (secret) *secret=strdup(&(rv[1][19]));
-    printf("key:    '%s'\nsecret: '%s'\n",*token, *secret); // XXX 
+    printf("key:    '%s'\nsecret: '%s'\n",*token, *secret); // XXX token&secret may be NULL.
   }
   if(rv) free(rv);
   return ok;
 }
 
 /** 
- * an example requesting a request-token from an oAuth service-provider
+ * an example requesting a request-token from an OAuth service-provider
  * exchaning it with an access token
  * and make an example request.
  * exercising either the oauth-HTTP GET or POST function.
@@ -119,7 +119,7 @@ int oauth_consumer_example(int use_post) {
   if(req_url) free(req_url);
   if(postarg) free(postarg);
 
-  if (strcmp(reply,"bar=baz&method=foo%2520bar")) return (5);
+  if (strcmp(reply,"bar=baz&method=foo+bar")) return (5);
 
   if(reply) free(reply);
   if(t_key) free(t_key);
