@@ -47,6 +47,19 @@ int main (int argc, char **argv) {
       "&a1[ak2]=av2",
   "GET&http%3A%2F%2Fexample.com%2F&a1%255Baa1%255D%255Baak1%255D%3Daav1%26a1%255Baa1%255D%255Baak2%255D%3Daav2%26a1%255Bak1%255D%3Dav1%26a1%255Bak2%255D%3Dav2%26k1%3Dv1%26k2%3Dv2");
 
+  if (loglevel) printf("\n *** Testing http://tools.ietf.org/html/rfc5849 example.\n");
+
+  fail|=test_request("GET", "http://example.com" 
+      "/request?b5=%3D%253D&a3=a&c%40=&a2=r%20b"
+      "&c2&a3=2+q"
+      "&oauth_consumer_key=9djdj82h48djs9d2"
+      "&oauth_token=kkk9d7dh3k39sjv7"
+      "&oauth_signature_method=HMAC-SHA1"
+      "&oauth_timestamp=137131201"
+      "&oauth_nonce=7d8f3e4a"
+      "&oauth_signature=djosJKDKJSD8743243%2Fjdk33klY%3D",
+   "GET&http%3A%2F%2Fexample.com%2Frequest&a2%3Dr%2520b%26a3%3D2%2520q%26a3%3Da%26b5%3D%253D%25253D%26c%2540%3D%26c2%3D%26oauth_consumer_key%3D9djdj82h48djs9d2%26oauth_nonce%3D7d8f3e4a%26oauth_signature_method%3DHMAC-SHA1%26oauth_timestamp%3D137131201%26oauth_token%3Dkkk9d7dh3k39sjv7");
+
   if (loglevel) printf("\n *** Testing body hash calculation.\n");
 
   char *bh;
